//
//     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
//     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
//     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
//     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
//     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
//     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
//     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
//     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
//     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
//     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
//     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//     FOR A PARTICULAR PURPOSE.
//
//     (c) Copyright 2005 Xilinx, Inc.
//     All rights reserved.
//
/*
-------------------------------------------------------------------------------
   Title      : AUDIO FILTER DEMO DESIGN FOR THE XUP-V2Pro
   Project    : XUP-V2Pro 
-------------------------------------------------------------------------------
   File       : PB_SAMPLE.v
   Company    : Xilinx, Inc.
   Created    : 2005/03/30
   Last Update: 2005/03/30
   Copyright  : (c) Xilinx Inc, 2005
-------------------------------------------------------------------------------
   Uses       : 
-------------------------------------------------------------------------------
   Used by    : 
-------------------------------------------------------------------------------
   Description: This module samples the LEFT, CENTER and RIGHT pushbuttons and 
 				creates the audio filter mux selects based on the pushbutton status.

If no PBs are pressed OR more than 1 PB is pressed mux_select <- 0. no filter selected
If the LEFT PB is pressed   mux_select <- 1. LPF selected
If the CENTER PB is pressed mux_select <- 2. BPF selected
If the RIGHT PB is pressed  mux_select <- 3. HPF selected
-------------------------------------------------------------------------------
   Revisions  :
   Date        Version  Author  	  Description
   2005/03/30  1.0      Ballantyne    Initial Release

-------------------------------------------------------------------------------
*/

module pb_sample(
clock,
reset,
left,
center,
right,
mux_select);

input clock;			// 100 mhz system clock
input reset;			// system reset
input left;				// LEFT PB selects a LPF filter
input center;			// CENTER PB selects a BPF filter
input right;			// RIGHT PB selects a HPF filter
output [1:0] mux_select;// filter function selects for the mux

reg [1:0] mux_select;
reg [22:0] pb_count;
reg left_in;
reg center_in;
reg right_in;
wire left;
wire center;
wire right;

// register the PB inputs
	always @ (posedge clock) begin
		left_in <= left;
		center_in <= center;
		right_in <= right;
	end

// create a counter to sample the registered PB inputs
	always @ (posedge clock or posedge reset) begin
	if (reset) begin
		pb_count <= 0;
		end
	else begin
		pb_count <= pb_count +1;
		end
	end

// create the mux selects
always @ (posedge clock or posedge reset) begin
	if (reset) begin
		mux_select <= 0;
		end
	else if (pb_count == 23'h7FFFFF) begin		// sample the PBs at ~12Hz
		if ({left_in,center_in,right_in} == 3'b011) begin
			mux_select <= 1;
			end
		else if ({left_in,center_in,right_in} == 3'b101) begin
			mux_select <= 2;
			end
		else if ({left_in,center_in,right_in} == 3'b110) begin
			mux_select<= 3;
			end
		else begin
			mux_select <= 0;
			end
		end
	end
endmodule

	