--
--     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
--     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
--     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
--     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
--     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
--     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
--     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
--     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
--     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
--     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
--     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
--     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
--     FOR A PARTICULAR PURPOSE.
--
--     (c) Copyright 2005 Xilinx, Inc.
--     All rights reserved.
--
-------------------------------------------------------------------------------
--
--   Title      : AUDIO FILTER DEMO DESIGN FOR THE XUP-V2Pro
--
--   Project    : XUP-V2Pro 
-------------------------------------------------------------------------------
--   File       : buttons.vhd  -- converted from PB_SAMPLE.v
--   Company    : Xilinx, Inc.
--   Created    : 2005/03/30
--   Last Update: 2005/03/30
--   Copyright  : (c) Xilinx Inc, 2005
-------------------------------------------------------------------------------
--   Uses       : 
-------------------------------------------------------------------------------
--   Used by    : 
-------------------------------------------------------------------------------
--   Description: This module samples the LEFT, CENTER and RIGHT pushbuttons and 
--                                creates the audio filter mux selects based on the pushbutton status.
--
--If no PBs are pressed OR more than 1 PB is pressed mux_select <- 0. no filter selected
--If the LEFT PB is pressed   mux_select <- 1. LPF selected
--If the CENTER PB is pressed mux_select <- 2. BPF selected
--If the RIGHT PB is pressed  mux_select <- 3. HPF selected
-------------------------------------------------------------------------------
--   Revisions  :
--   Date        Version  Author  	  Description
--   2005/04/06     1.0    Mark paluszkiewicz
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;


entity pb_sample is
port (
clock : in std_logic; 
reset: in std_logic;
left: in std_logic;
center: in std_logic;
right: in std_logic;
mux_select : out std_logic_vector(1 downto 0)
);
end pb_sample;


architecture rtl of pb_sample is

  signal reg_mux_select : std_logic_vector(1 downto 0);
  signal pb_count : std_logic_vector(15 downto 0);
  signal reg_left_in : std_logic;
  signal reg_center_in : std_logic;
  signal reg_right_in : std_logic;
  signal mux_sel : std_logic_vector(2 downto 0);


begin

mux_sel <= reg_left_in & reg_center_in & reg_right_in;
mux_select <=  reg_mux_select;


-- register the PB inputs
process (clock, reset)
begin
   if reset='1' then   
      reg_left_in <= '0';
      reg_center_in <= '0';
      reg_right_in <= '0';
   elsif (clock'event and clock='1') then 
      reg_left_in <= left;
      reg_center_in <= center;
      reg_right_in <= right;
   end if;
end process;


-- create a counter to sample the registered PB inputs
process (clock, reset) 
begin
   if reset='1' then 
      pb_count <= (others => '0');
   elsif clock='1' and clock'event then
         pb_count <= pb_count + 1;
   end if;
end process;

-- create the mux selects
process(clock,reset,mux_sel )
begin
   if ( reset = '1') then
      reg_mux_select <= "00";
   elsif ( clock'event and clock ='1') then 
    if (pb_count = "1111111111111111") then 
      case mux_sel is
         when "000" => reg_mux_select <= "00";
         when "011" => reg_mux_select <= "01";
         when "101" => reg_mux_select <= "10";
         when "110" => reg_mux_select <= "11";
         when others => reg_mux_select <= "00";
      end case;
    end if;
   end if;
end process;

end rtl;


