--------------------------------------------------------------------------------
-- Company: 
-- Engineer:
--
-- Create Date:    11:55:19 04/13/05
-- Design Name:    
-- Module Name:    filter_load_st_mach - Behavioral
-- Project Name:   
-- Target Device:  
-- Tool versions:  
-- Description:
--
-- Dependencies:
-- 
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
-- 
--------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;


--library UNISIM;
--use UNISIM.VComponents.all;

entity filter_load_st_mach is
    Port ( filter_clk        : in std_logic;
           reset             : in std_logic;
           valid_ac97_sample : in std_logic;
           filter_ld         : out std_logic;
           filter_ce         : out std_logic;
           reg_output        : out std_logic;
           fft_fifo_we       : out std_logic
           );
end filter_load_st_mach;

architecture Behavioral of filter_load_st_mach is


  type state_type is (idle, load, run_filter, reg_result ); 
  signal state, next_state : state_type; 
  signal en_sda_count : std_logic;
  signal reset_sda_count : std_logic;  
  signal sda_count : std_logic_vector(4 downto 0);
  signal filter_ld_i : std_logic;
  signal filter_ce_i : std_logic;
  signal comb_filter_ce_i : std_logic;
  signal reg_output_i : std_logic;
  signal even_reg_output : std_logic;
  signal odd_reg_output : std_logic;
  signal reg_output_i1 : std_logic;

begin
comb_filter_ce_i <=  filter_ce_i or  filter_ld_i;
 fft_fifo_we <= even_reg_output AND reg_output_i1;
reg_output <=reg_output_i1;

process (filter_clk)
begin
   if filter_clk'event and filter_clk='1' then  
      if Reset='1' then   
        even_reg_output <= '1';
        odd_reg_output <= '0';
      elsif reg_output_i ='1' then
        even_reg_output <=  NOT even_reg_output;
        odd_reg_output <=   NOT odd_reg_output;
      end if;
   end if;
end process;



process (filter_clk, reset) 
begin
   if reset='1' then 
      sda_count  <= (others => '0');
      elsif filter_clk='1' and filter_clk'event then
         if reset_sda_count ='1' then
            sda_count <= "00000";
         else 
            sda_count <= sda_count + 1;
         end if;
      end if;
end process;


--Insert the following in the architecture after the begin keyword
   SYNC_PROC: process (filter_clk, RESET)
   begin
      if (reset='1') then
         state <= idle;
         filter_ld <= '0';
         filter_ce <= '0';
         reg_output_i1 <= '0';
      elsif (filter_clk'event and filter_clk = '1') then
         state <= next_state;
         filter_ld <= filter_ld_i;
         filter_ce <= comb_filter_ce_i;
         reg_output_i1 <= reg_output_i;
      end if;
   end process;
 

   OUTPUT_DECODE_LOAD: process (state)
   begin
      if state = load then
         reset_sda_count <= '1';
         filter_ld_i <= '1';
      else
         reset_sda_count <= '0';
         filter_ld_i <= '0';
      end if;
   end process;

  OUTPUT_DECODE_RUN: process (state)
   begin
      if   state = run_filter then
         filter_ce_i<= '1';
      else
         filter_ce_i <= '0';
         end if;
   end process;

  OUTPUT_DECODE_REG_RESULT: process (state)
   begin
      if   state = reg_result then
         reg_output_i<= '1';
      else
         reg_output_i <= '0';
         end if;
   end process;


   NEXT_STATE_DECODE: process (state ,valid_ac97_sample, sda_count)
   begin
      next_state <= state;  --default is to stay in current state
      case (state) is
         when idle  =>
            if  valid_ac97_sample = '1' then
               next_state <=load ;
               else
               next_state <= idle;
             end if;
          when load =>
               next_state <= run_filter;
         when run_filter =>
            if  sda_count = "01111" then
             next_state <= reg_result;
               else
             next_state <= run_filter;
             end if;
          when reg_result => 
               next_state <= idle;
         when others =>
            next_state <= idle;
      end case;      
   end process;

end Behavioral;
